# Generated by roxygen2: do not edit by hand

export(checkpoint)
export(checkpointArchives)
export(checkpointRemove)
export(getAccessDate)
export(getValidSnapshots)
export(mranUrl)
export(scanForPackages)
export(setSnapshot)
export(unCheckpoint)
importFrom(utils,Stangle)
importFrom(utils,available.packages)
importFrom(utils,capture.output)
importFrom(utils,compareVersion)
importFrom(utils,download.file)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,write.table)
